@@ -198,6 +198,16 @@ unmap_event_cb (GtkWidget *width,
 	return FALSE;
 }
 
+static gboolean
+grab_broken_event_cb (GtkWidget *widget,
+		      GdkEventGrabBroken *event,
+		      EphyGesture *gesture)
+{
+	ephy_gesture_stop (gesture, GDK_CURRENT_TIME /* FIXME? */);
+
+	return FALSE;
+}
+
 static void
 grab_notify_cb (GtkWidget *widget,
 		gboolean was_grabbed,
@@ -229,6 +239,8 @@ ephy_gesture_start (EphyGesture *gesture)
 			  G_CALLBACK (key_press_event_cb), gesture);
 	g_signal_connect (priv->window, "unmap-event",
 			  G_CALLBACK (unmap_event_cb), gesture);
+	g_signal_connect (priv->window, "grab-broken-event",
+			  G_CALLBACK (grab_broken_event_cb), gesture);
 
 	child = gtk_bin_get_child (GTK_BIN (priv->window));
 	g_signal_connect (child, "grab-notify",
